<?php
wp_enqueue_script('jquery');// Include jquery
automatic_feed_links();
register_sidebar(array(
	'name'=>'sidebar',
    'before_widget' => '<li id="%1$s" class="widget %2$s">',
    'after_widget' => '</li>',
    'before_title' => '<h2 class="widgettitle">',
    'after_title' => '</h2>',
));

function attach_theme_settings() {
	include_once('lib/theme-options/theme-options.php');
	include_once('options/theme-options.php');
	include_once('options/navigation-options.php');
	// include_once('options/theme-widgets.php');
}

attach_theme_settings();

/**
 * Returns page object by page slug
 * @param page_name - page slug
 * @return page object
 */
function _get_page_by_name($page_name, $output = OBJECT) { 
    global $wpdb; 
    $page = $wpdb->get_var( $wpdb->prepare( "SELECT ID FROM $wpdb->posts WHERE post_name = %s AND post_type='page'", $page_name )); 
    if ( $page ) 
        return get_page($page, $output); 
    return null; 
}

/**
 * Shortcut function for acheiving
 * $no_nav_pages = _get_page_by_name('no-nav-pages');
 * wp_list_pages('sort_column=menu_order&exclude_tree=' . $no_nav_pages->ID);
 * with:
 * wp_list_pages('sort_column=menu_order&' . exclude_no_nav());
 */
function exclude_no_nav($no_nav_pages_slug='no-nav-pages') {
    $no_nav_page = _get_page_id_by_name($no_nav_pages_slug);
    return "exclude_tree=$no_nav_page";
}
/**
 * Very similiar to _get_page_by_name() but it returns only page ID instead 
 * whole page object
 */
function _get_page_id_by_name($name) {
    $page = _get_page_by_name($name);
    return $page->ID;
}
/**
 * Checks if particular page ID has parent with particular slug
 */
$__has_parent_depth = 0;
function has_parent($id, $parent_name) {
    global $__has_parent_depth;
    $__has_parent_depth++;
    if ($__has_parent_depth==100) {
    	exit('too much recursion');
    }
    $post = get_post($id);
    
    if ($post->post_name==$parent_name) {
    	return true;
    }
    if ($post->post_parent==0) {
    	return false;
    }
    $__has_parent_depth--;
    return has_parent($post->post_parent, $parent_name);
}

/**
 * Example function for printing comments
 * NOTE: This function opens one more tag than it's closing. This is needed because
 * wordpress is closing the tag at the end. 
 */
function print_comment($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment; ?>
	<li <?php comment_class('comment'); ?>>
		<div class="comment-body" id="comment-<?php comment_ID() ?>">
			<?php echo get_avatar($comment, 70, get_bloginfo('stylesheet_directory') . '/images/avatar.gif'); ?>
			<p class="author">
				<?php comment_author_link() ?>
			</p>
			<p class="comment-meta">
				<?php comment_date() ?> at <?php comment_time() ?>
			</p>
			<div class="comment-content">
				<?php if ($comment->comment_approved == '0') : ?>
			        <em><?php _e('Your comment is awaiting moderation.') ?></em><br />
			    <?php endif; ?>
			    
				<?php comment_text() ?>
				<div class="alignleft"><?php edit_comment_link(__('(Edit)'),'  ','') ?></div>
				
			</div>
			<div class="reply">
		        <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
		    </div>
			<div class="cl">&nbsp;</div>
		</div>
	<?php
}

# crawls the pages tree up to top level page ancestor 
# and returns that page as object
function get_page_ancestor($page_id) {
    $page_obj = get_page($page_id);
    while($page_obj->post_parent!=0) {
        $page_obj = get_page($page_obj->post_parent);
    }
    return get_page($page_obj->ID);
}

/**
 * Some fields in administration use built-in WP thickbox
 */
function thickbox_css_hook() {
	wp_enqueue_style('thickbox');
}
add_action('admin_head', 'thickbox_css_hook');

/**
 * Returns posts page as object. If there is no page for posts null is returned
 */
function get_posts_page() {
    $posts_page_id = get_option('page_for_posts');
    if ($posts_page_id) {
    	return get_page($posts_page_id);
    }
    return null;
}

function choco_print_pages_nav() {
	global $post;
	$current_page_ancestor = get_page_ancestor($post->ID);
	$excluded = get_option('header_nav_pages_exclude');
	if ($excluded) {
		$excluded_pages = "exclude=" . implode(',', $excluded);
	} else {
		$excluded_pages = '';
	}
	
    $pages = get_pages("parent=0&child_of=0&sort_column=menu_order&$excluded_pages");
    
    $html = '';
    foreach ($pages as $page) {
    	$classes = array();
    	if (is_page() && $current_page_ancestor->ID==$page->ID) {
    		$classes[] = "current_page_item";
    	}
    	$html .= '<li class="' . implode(' ', $classes) . '"><a href="' . get_permalink($page->ID) . '"><span>' . apply_filters('the_title', $page->post_title) . '</span></a></li>';
    }
    echo $html;
}
function choco_print_categories_nav() {
    $excluded = get_option('header_nav_categories_exclude');
	if ($excluded) {
		$excluded_pages = "exclude=" . implode(',', $excluded);
	} else {
		$excluded_pages = '';
	}
	
    $categories = get_categories("$excluded_pages");
	
    $html = '';
    
    foreach ($categories as $category) {
    	$classes = array();
    	if (is_category($category->term_id)) {
    		$classes[] = "current_page_item";
    	}
    	$html .= '<li class="' . implode(' ', $classes) . '"><a href="' . get_category_link($category->term_id) . '"><span>' . $category->name . '</span></a></li>';
    }
    echo $html;
}
function choco_print_header() {
    $nav_type = get_option('nav_type');
    if ($nav_type=='pages') {
    	choco_print_pages_nav();
    } else if ($nav_type=='categories') {
    	choco_print_categories_nav();
    } else /*shouldn't happen*/ {
    	choco_print_pages_nav();
    }
}
function choco_get_body_style() {
    $bg_color = get_option('background_color', '#3A2820');
    $bg_image = get_option('background_image');
    $bg_repeat = get_option('background_repeat');
    
    $style = 'background: ' . $bg_color;
    if ($bg_image) {
    	$style .= ' url(' . $bg_image . ') center top ' . $bg_repeat;
    }
    $style .= ';';
    
    return $style;
}
?>